FlipType

Enum FlipType 

pub enum FlipType {
    RR,
    NN,
    RN,
    NR,
}
Flip type

Variants



RR

Flip on both odd and even pages



NN

No flip on both odd and even pages



RN

Flip on odd pages, no flip on even pages



NR

Flip on even pages, no flip on odd pages

Implementations

Source

impl FlipType

pub fn should_reverse(&self, odd_even: OddEven) -> bool