pub enum FlipType {
RR,
NN,
RN,
NR,
}Expand description
Flip type
Variants
RR
Flip on both odd and even pages
NN
No flip on both odd and even pages
RN
Flip on odd pages, no flip on even pages
NR
Flip on even pages, no flip on odd pages
Implementations